@@ -4,7 +4,7 @@
 //! Minimum type is like this:
 //!
 //! ```rust
-//! #[macro_use] extern crate quick_error2;
+//! #[macro_use] extern crate quick_error;
 //! # fn main() {}
 //!
 //! quick_error! {
@@ -25,7 +25,7 @@
 //! You may add arbitrary parameters to any struct variant:
 //!
 //! ```rust
-//! # #[macro_use] extern crate quick_error2;
+//! # #[macro_use] extern crate quick_error;
 //! # fn main() {}
 //! #
 //! quick_error! {
@@ -45,38 +45,32 @@
 //! Now you might have noticed trailing braces `{}`. They are used to define
 //! implementations. By default:
 //!
-//! * `Error::description()` returns variant name as static string
 //! * `Error::source()` returns None (even if type wraps some value)
-//! * `Display` outputs `description()`
+//! * `Display` outputs debug representation
 //! * No `From` implementations are defined
 //!
-//! To define description simply add `description(value)` inside braces:
-//!
 //! ```rust
-//! # #[macro_use] extern crate quick_error2;
+//! # #[macro_use] extern crate quick_error;
 //! # fn main() {}
 //! #
 //! quick_error! {
 //!     #[derive(Debug)]
 //!     pub enum SomeError {
 //!         Io(err: std::io::Error) {
-//!             description(err.description())
+//!             display("{}", err)
 //!         }
 //!         Utf8(err: std::str::Utf8Error) {
-//!             description("utf8 error")
+//!             display("utf8 error")
 //!         }
 //!     }
 //! }
 //! ```
 //!
-//! Normal rules for borrowing apply. So most of the time description either
-//! returns constant string or forwards description from enclosed type.
-//!
 //! To change `source` method to return some error, add `source(value)`, for
 //! example:
 //!
 //! ```rust
-//! # #[macro_use] extern crate quick_error2;
+//! # #[macro_use] extern crate quick_error;
 //! # fn main() {}
 //! #
 //! quick_error! {
@@ -84,14 +78,12 @@
 //!     pub enum SomeError {
 //!         Io(err: std::io::Error) {
 //!             source(err)
-//!             description(err.description())
 //!         }
 //!         Utf8(err: std::str::Utf8Error) {
-//!             description("utf8 error")
+//!             display("utf8 error")
 //!         }
 //!         Other(err: Box<std::error::Error>) {
 //!             source(&**err)
-//!             description(err.description())
 //!         }
 //!     }
 //! }
@@ -104,7 +96,7 @@
 //! for example:
 //!
 //! ```rust
-//! # #[macro_use] extern crate quick_error2;
+//! # #[macro_use] extern crate quick_error;
 //! # fn main() {}
 //! #
 //! quick_error! {
@@ -124,19 +116,19 @@
 //! `display(x) -> (pattern, ..args)`, where `x` sets the name of the reference.
 //!
 //! ```rust
-//! # #[macro_use] extern crate quick_error2;
+//! # #[macro_use] extern crate quick_error;
 //! # fn main() {}
 //! #
-//! use std::error::Error; // put methods like `description()` of this trait into scope
+//! use std::error::Error; // put methods like `source()` of this trait into scope
 //!
 //! quick_error! {
 //!     #[derive(Debug)]
 //!     pub enum SomeError {
 //!         Io(err: std::io::Error) {
-//!             display(x) -> ("{}: {}", x.description(), err)
+//!             display(x) -> ("I/O: {}", err)
 //!         }
 //!         Utf8(err: std::str::Utf8Error) {
-//!             display(self_) -> ("{}, valid up to {}", self_.description(), err.valid_up_to())
+//!             display(self_) -> ("UTF-8 error. Valid up to {}", err.valid_up_to())
 //!         }
 //!     }
 //! }
@@ -148,7 +140,7 @@
 //! For example, to convert simple wrapper use bare `from()`:
 //!
 //! ```rust
-//! # #[macro_use] extern crate quick_error2;
+//! # #[macro_use] extern crate quick_error;
 //! # fn main() {}
 //! #
 //! quick_error! {
@@ -167,7 +159,7 @@
 //! the `from(type)` form:
 //!
 //! ```rust
-//! # #[macro_use] extern crate quick_error2;
+//! # #[macro_use] extern crate quick_error;
 //! # fn main() {}
 //! #
 //! quick_error! {
@@ -185,7 +177,7 @@
 //! value conversions:
 //!
 //! ```rust
-//! # #[macro_use] extern crate quick_error2;
+//! # #[macro_use] extern crate quick_error;
 //! # fn main() {}
 //! #
 //! quick_error! {
@@ -210,12 +202,12 @@
 //! the error. We need a longer example to demonstrate this:
 //!
 //! ```rust
-//! # #[macro_use] extern crate quick_error2;
+//! # #[macro_use] extern crate quick_error;
 //! # use std::io;
 //! # use std::fs::File;
 //! # use std::path::{Path, PathBuf};
 //! #
-//! use quick_error2::ResultExt;
+//! use quick_error::ResultExt;
 //!
 //! quick_error! {
 //!     #[derive(Debug)]
@@ -256,7 +248,7 @@
 //!
 //! More info on context in [this article](http://bit.ly/1PsuxDt).
 //!
-//! All forms of `from`, `display`, `description`, `source`, and `context`
+//! All forms of `from`, `display`, `source`, and `context`
 //! clauses can be combined and put in arbitrary order. Only `from` and
 //! `context` can be used multiple times in single variant of enumeration.
 //! Docstrings are also okay.  Empty braces can be omitted as of quick_error
@@ -268,7 +260,7 @@
 //! wrapped by public structure:
 //!
 //! ```rust
-//! #[macro_use] extern crate quick_error2;
+//! #[macro_use] extern crate quick_error;
 //! # fn main() {}
 //!
 //! quick_error! {
@@ -378,9 +370,6 @@ macro_rules! quick_error {
         }
 
         impl ::std::error::Error for $strname {
-            fn description(&self) -> &str {
-                self.0.description()
-            }
             fn source(&self) -> Option<&(dyn std::error::Error + 'static)> {
                 self.0.source()
             }
@@ -463,8 +452,6 @@ macro_rules! quick_error {
         queue [ #[$qmeta:meta] $( $tail:tt )*]
     ) => {
         quick_error!(SORT [$( $def )*]
-            enum [$( $(#[$emeta])* => $eitem $(( $($etyp),* ))* )*
-                     $(#[$bmeta])* => $bitem: $bmode $(( $($btyp),* ))*]
             items [$($( #[$imeta:meta] )*
                       => $iitem: $imode [$( $ivar:$ityp ),*] {$( $ifuncs )*} )*
                      $bitem: $bmode [$( $bvar:$btyp ),*] {} ]
@@ -481,7 +468,7 @@ macro_rules! quick_error {
     ) => {
         quick_error!(SORT [$( $def )*]
             items [$( $(#[$imeta])* => $iitem: $imode [$( $ivar:$ityp ),*] {$( $ifuncs )*} )*]
-            buf [$( #[$bmeta] )* => $bitem: TUPLE [$( $qvar:$qtyp ),*] ]
+            buf [$( #[$bmeta] )* => $bitem: TUPLE [$( $qvar:$qtyp ),+] ]
             queue [$( $tail )*]
         );
     };
@@ -495,7 +482,7 @@ macro_rules! quick_error {
     ) => {
         quick_error!(SORT [$( $def )*]
             items [$( $(#[$imeta])* => $iitem: $imode [$( $ivar:$ityp ),*] {$( $ifuncs )*} )*]
-            buf [$( #[$bmeta] )* => $bitem: STRUCT [$( $qvar:$qtyp ),*] ]
+            buf [$( #[$bmeta] )* => $bitem: STRUCT [$( $qvar:$qtyp ),+] ]
             queue [$( $tail )*]);
     };
     // Add struct enum-variant, with excess comma - e.g. { descr: &'static str, }
@@ -508,7 +495,7 @@ macro_rules! quick_error {
     ) => {
         quick_error!(SORT [$( $def )*]
             items [$( $(#[$imeta])* => $iitem: $imode [$( $ivar:$ityp ),*] {$( $ifuncs )*} )*]
-            buf [$( #[$bmeta] )* => $bitem: STRUCT [$( $qvar:$qtyp ),*] ]
+            buf [$( #[$bmeta] )* => $bitem: STRUCT [$( $qvar:$qtyp ),+] ]
             queue [$( $tail )*]);
     };
     // Add braces and flush always on braces
@@ -570,7 +557,7 @@ macro_rules! quick_error {
         pub enum $name {
             $(
                 $(#[$imeta])*
-                $iitem $(($( $ttyp ),*))* $({$( $svar: $styp ),*})*,
+                $iitem $(($( $ttyp ),+))* $({$( $svar: $styp ),*})*,
             )*
         }
     };
@@ -588,7 +575,7 @@ macro_rules! quick_error {
         enum $name {
             $(
                 $(#[$imeta])*
-                $iitem $(($( $ttyp ),*))* $({$( $svar: $styp ),*})*,
+                $iitem $(($( $ttyp ),+))* $({$( $svar: $styp ),*})*,
             )*
         }
     };
@@ -614,7 +601,7 @@ macro_rules! quick_error {
     ) => {
         quick_error!(ENUM_DEFINITION [ $($def)* ]
             body [$($( #[$imeta] )* => $iitem ($(($( $ttyp ),+))*) {$({$( $svar: $styp ),*})*} )*
-                    $( #[$qmeta] )* => $qitem (($( $qtyp ),*)) {} ]
+                    $( #[$qmeta] )* => $qitem (($( $qtyp ),+)) {} ]
             queue [ $($queue)* ]
         );
     };
@@ -667,20 +654,6 @@ macro_rules! quick_error {
         #[allow(unused_doc_comment)]
         #[allow(unused_doc_comments)]
         impl ::std::error::Error for $name {
-            fn description(&self) -> &str {
-                match *self {
-                    $(
-                        $(#[$imeta])*
-                        quick_error!(ITEM_PATTERN
-                            $name $item: $imode [$( ref $var ),*]
-                        ) => {
-                            quick_error!(FIND_DESCRIPTION_IMPL
-                                $item: $imode self fmt [$( $var ),*]
-                                {$( $funcs )*})
-                        }
-                    )*
-                }
-            }
             fn source(&self) -> Option<&(dyn std::error::Error + 'static)> {
                 match *self {
                     $(
@@ -733,29 +706,9 @@ macro_rules! quick_error {
         { }
     ) => {
         |self_: &$name, f: &mut ::std::fmt::Formatter| {
-            write!(f, "{}", ::std::error::Error::description(self_))
+            write!(f, "{:?}", self_)
         }
     };
-    (FIND_DESCRIPTION_IMPL $item:ident: $imode:tt $me:ident $fmt:ident
-        [$( $var:ident ),*]
-        { description($expr:expr) $( $tail:tt )*}
-    ) => {
-        $expr
-    };
-    (FIND_DESCRIPTION_IMPL $item:ident: $imode:tt $me:ident $fmt:ident
-        [$( $var:ident ),*]
-        { $t:tt $( $tail:tt )*}
-    ) => {
-        quick_error!(FIND_DESCRIPTION_IMPL
-            $item: $imode $me $fmt [$( $var ),*]
-            {$( $tail )*})
-    };
-    (FIND_DESCRIPTION_IMPL $item:ident: $imode:tt $me:ident $fmt:ident
-        [$( $var:ident ),*]
-        { }
-    ) => {
-        stringify!($item)
-    };
     (FIND_SOURCE_IMPL $item:ident: $imode:tt
         [$( $var:ident ),*]
         { source($expr:expr) $( $tail:tt )*}
@@ -971,8 +924,6 @@ macro_rules! quick_error {
     => { quick_error!(ERROR_CHECK $imode $($tail)*); };
     (ERROR_CHECK $imode:tt display($pattern: expr, $( $exprs:tt )*) $( $tail:tt )*)
     => { quick_error!(ERROR_CHECK $imode $($tail)*); };
-    (ERROR_CHECK $imode:tt description($expr:expr) $( $tail:tt )*)
-    => { quick_error!(ERROR_CHECK $imode $($tail)*); };
     (ERROR_CHECK $imode:tt source($expr:expr) $($tail:tt)*)
     => { quick_error!(ERROR_CHECK $imode $($tail)*); };
     (ERROR_CHECK $imode:tt from() $($tail:tt)*)
@@ -1041,7 +992,6 @@ mod test {
     fn bare_item_direct() {
         assert_eq!(format!("{}", Bare::One), "One".to_string());
         assert_eq!(format!("{:?}", Bare::One), "One".to_string());
-        assert_eq!(Bare::One.description(), "One".to_string());
         assert!(Bare::One.source().is_none());
     }
 
@@ -1050,7 +1000,6 @@ mod test {
         let err: &Error = &Bare::Two;
         assert_eq!(format!("{}", err), "Two".to_string());
         assert_eq!(format!("{:?}", err), "Two".to_string());
-        assert_eq!(err.description(), "Two".to_string());
         assert!(err.source().is_none());
     }
 
@@ -1079,7 +1028,6 @@ mod test {
             format!("{:?}", Wrapper::from(Wrapped::One)),
             "Wrapper(One)".to_string()
         );
-        assert_eq!(Wrapper::from(Wrapped::One).description(), "One".to_string());
     }
 
     quick_error! {
@@ -1088,19 +1036,16 @@ mod test {
             /// ParseFloat Error
             ParseFloatError(err: ParseFloatError) {
                 from()
-                description(err.description())
                 display("parse float error: {err}", err=err)
                 source(err)
             }
             Other(descr: &'static str) {
-                description(descr)
                 display("Error: {}", descr)
             }
             /// FromUtf8 Error
             FromUtf8Error(err: Utf8Error, source: Vec<u8>) {
                 source(err)
-                display(me) -> ("{desc} at index {pos}: {err}", desc=me.description(), pos=err.valid_up_to(), err=err)
-                description("utf8 error")
+                display(me) -> ("{desc} at index {pos}: {err}", desc="utf8 error", pos=err.valid_up_to(), err=err)
                 from(err: FromUtf8Error) -> (err.utf8_error().clone(), err.into_bytes())
             }
             Discard {
@@ -1121,7 +1066,6 @@ mod test {
             format!("{:?}", err),
             format!("ParseFloatError({:?})", source)
         );
-        assert_eq!(err.description(), source.description());
         assert_eq!(
             format!("{:?}", err.source().unwrap()),
             format!("{:?}", source)
@@ -1134,7 +1078,6 @@ mod test {
         let err: &Error = &TupleWrapper::Other(desc);
         assert_eq!(format!("{}", err), format!("Error: {}", desc));
         assert_eq!(format!("{:?}", err), format!("Other({:?})", desc));
-        assert_eq!(err.description(), desc);
         assert!(err.source().is_none());
     }
 
@@ -1149,7 +1092,7 @@ mod test {
             format!("{}", err),
             format!(
                 "{desc} at index {pos}: {source}",
-                desc = err.description(),
+                desc = "utf8 error",
                 pos = source.valid_up_to(),
                 source = source
             )
@@ -1158,7 +1101,6 @@ mod test {
             format!("{:?}", err),
             format!("FromUtf8Error({:?}, {:?})", source, invalid_utf8)
         );
-        assert_eq!(err.description(), "utf8 error");
         assert_eq!(
             format!("{:?}", err.source().unwrap()),
             format!("{:?}", source)
@@ -1187,7 +1129,6 @@ mod test {
         let err: TupleWrapper = From::from("hello");
         assert_eq!(format!("{}", err), format!("Discard"));
         assert_eq!(format!("{:?}", err), format!("Discard"));
-        assert_eq!(err.description(), "Discard");
         assert!(err.source().is_none());
     }
 
@@ -1196,7 +1137,6 @@ mod test {
         let err: TupleWrapper = TupleWrapper::Singleton;
         assert_eq!(format!("{}", err), format!("Just a string"));
         assert_eq!(format!("{:?}", err), format!("Singleton"));
-        assert_eq!(err.description(), "Singleton");
         assert!(err.source().is_none());
     }
 
@@ -1206,13 +1146,11 @@ mod test {
             // Utf8 Error
             Utf8Error{ err: Utf8Error, hint: Option<&'static str> } {
                 source(err)
-                display(me) -> ("{desc} at index {pos}: {err}", desc=me.description(), pos=err.valid_up_to(), err=err)
-                description("utf8 error")
+                display(me) -> ("{desc} at index {pos}: {err}", desc="utf8 error", pos=err.valid_up_to(), err=err)
                 from(err: Utf8Error) -> { err: err, hint: None }
             }
             // Utf8 Error
             ExcessComma { descr: &'static str, } {
-                description(descr)
                 display("Error: {}", descr)
             }
         }
@@ -1232,7 +1170,7 @@ mod test {
             format!("{}", err),
             format!(
                 "{desc} at index {pos}: {source}",
-                desc = err.description(),
+                desc = "utf8 error",
                 pos = source.valid_up_to(),
                 source = source
             )
@@ -1245,7 +1183,6 @@ mod test {
                 Some("nonsense")
             )
         );
-        assert_eq!(err.description(), "utf8 error");
         assert_eq!(
             format!("{:?}", err.source().unwrap()),
             format!("{:?}", source)
@@ -1275,7 +1212,6 @@ mod test {
             format!("{:?}", err),
             format!("ExcessComma {{ descr: {:?} }}", descr)
         );
-        assert_eq!(err.description(), descr);
         assert!(err.source().is_none());
     }
 
@@ -1340,7 +1276,9 @@ mod test {
 
     #[test]
     fn path_context() {
-        fn parse_utf<P: AsRef<Path>>(s: &[u8], p: P) -> Result<(), ContextErr> {
+        fn parse_utf<P: AsRef<Path>>(s: &[u8], p: P)
+            -> Result<(), ContextErr>
+        {
             ::std::str::from_utf8(s).context(p)?;
             Ok(())
         }
@@ -1379,7 +1317,7 @@ mod test {
             format!("{}", err),
             format!(
                 "{desc} at index {pos}: {cause}",
-                desc = err.description(),
+                desc = "utf8 error",
                 pos = cause.valid_up_to(),
                 cause = cause
             )
@@ -1392,7 +1330,6 @@ mod test {
                 Some("nonsense")
             )
         );
-        assert_eq!(err.description(), "utf8 error");
         assert_eq!(
             format!("{:?}", err.cause().unwrap()),
             format!("{:?}", cause)
